Python Interface
================

A Python interface ``sme`` is available, which can be installed from `PyPI <https://pypi.org/project/sme/>`_ with

.. code-block:: bash

    pip install sme

To get started, take a look at the :ref:`example-notebooks`, or the :ref:`api-reference`.

.. tip ::

    There is an online `colab notebook <https://colab.research.google.com/github/spatial-model-editor/spatial-model-editor/blob/master/docs/sme/notebooks/getting_started.ipynb>`_ where you can try it out in your browser without installing anything on your computer.

sme-contrib
-----------

There is also a separate Python module `sme-contrib <https://sme-contrib.readthedocs.io/en/latest/>`_, which contains additional functionality such as plotting and parameter fitting, and can be installed with

.. code-block:: bash

    pip install sme-contrib
